Rdocumentation
powered by
Learn R Programming
BEQI2 (version 1.0-1)
BEQI2dir: Create BEQI-2 Directory Structure
Description
Creates a BEQI2-directory structure and populates it with some relevant BEQI2-files. Users may wish to modify this directory structure and add their own data.
Usage
BEQI2dir(path = NULL)
Arguments