For each sample, the algorithm tries to convert taxa on the
genus level to the species level. Counts at the genus level
will be distributed over the species level proportional to
the available number of species.
Usage
genusToSpecies(id, taxon, count)
Arguments
Value
data.frame with three columns: id the sample
identifier, taxon the taxon name, and count
the count after genus to species conversion.